@@ -206,7 +206,7 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
         
         # FROM HERE BELOW, SPLIT OFF PSYCOPG2 VS NOT
         if ('psycopg2' in DB_BACKEND and (
-                ((dsabbr.upper() in ['CORE', 'BASE']) or
+                ((dsabbr.upper() in ['CORE', 'BASE', 'CHGS']) or
                  (dsabbr.upper() in ['CHGS'] and meta_is_long(load.get_meta()))
                     )
                 )
@@ -268,7 +268,7 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
         )
     
     # get helper functions
-    from pyhcup.db import pg_rawload, pg_staging, pg_shovel, pg_drop
+    from pyhcup.db import pg_rawload, pg_staging, pg_shovel, pg_wtl_shovel, pg_drop
     
     # let 'er rip
     meta = load.get_meta()
@@ -288,18 +288,28 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
     staging = pg_staging(cnxn, rawload, meta, state, year, pk_fields=pk_fields)
     logger.info('Staging table %s populated: %s' % (staging[0], load))
     
-    fields = [x for x in meta.field if x.lower() not in ['state', 'year']]
-    fields += ['state', 'year']
     
-    logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
-    affected_rows = pg_shovel(cnxn, staging[0], table, fields)
-    logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
+    if dsabbr in ['CHGS'] and not meta_is_long(meta):
+        # wide charges should get wide-to-long shoveled
+        category = dsabbr
+        logger.info('This is a wide-to-long pg load: %s' % (load))
+        logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
+        affected_rows = pg_wtl_shovel(cnxn, meta, category, staging[0], table)
+        logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
     
-    if drop_intermediate_tables:
-        drop_targets = [rawload, staging[0]]
-        logger.info('Dropping intermediate tables %s as part of load for %s' % (drop_targets, load))
-        for dtbl in drop_targets:
-            pg_drop(cnxn, dtbl)
+    else:
+        fields = [x for x in meta.field if x.lower() not in ['state', 'year']]
+        fields += ['state', 'year']
+        
+        logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
+        affected_rows = pg_shovel(cnxn, staging[0], table, fields)
+        logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
+        
+        if drop_intermediate_tables:
+            drop_targets = [rawload, staging[0]]
+            logger.info('Dropping intermediate tables %s as part of load for %s' % (drop_targets, load))
+            for dtbl in drop_targets:
+                pg_drop(cnxn, dtbl)
     
     # affected_rows will evaluate un-True in the case of any troubles
     if affected_rows:
